@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::InitTarget;
 
-our $DATE = '2017-08-01'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2017-08-04'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,7 +53,7 @@ Bencher::Scenario::LogGer::InitTarget - Benchmark init_target()
 
 =head1 VERSION
 
-This document describes version 0.011 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-01.
+This document describes version 0.012 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-04.
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/WeHVLEZACk'); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/YjnhbWBOx_'); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -119,7 +119,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/WeHVLEZACk'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/YjnhbWBOx_'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -127,7 +127,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/WeHVLEZACk'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/YjnhbWBOx_'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -143,13 +143,13 @@ Benchmark with default options (C<< bencher -m LogGer::InitTarget >>):
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
  | participant                                        | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
- | with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       350 |       1    | 0.00073 |       7 |
- | default                                            |      2.93 |       341 |       1.03 | 0.00023 |       9 |
- | with LGO:Composite (Screen+File)                   |      3.03 |       330 |       1.07 | 0.00013 |       7 |
- | with LGO:Composite (Screen)                        |      3.96 |       252 |       1.4  | 0.00013 |       8 |
- | with LGO:File                                      |      7.22 |       139 |       2.55 | 0.00012 |       7 |
- | with LGO:Composite (0 outputs)                     |      7.3  |       140 |       2.6  | 0.00022 |       7 |
- | with LGO:Screen                                    |      7.3  |       140 |       2.6  | 0.00027 |       7 |
+ | with LGO:Composite (Screen+File & pattern layouts) |      2.76 |       363 |        1   | 0.00019 |       8 |
+ | default                                            |      2.8  |       350 |        1   | 0.00074 |       8 |
+ | with LGO:Composite (Screen+File)                   |      3    |       340 |        1.1 | 0.0008  |       7 |
+ | with LGO:Composite (Screen)                        |      4    |       250 |        1.4 | 0.00074 |       7 |
+ | with LGO:File                                      |      5    |       200 |        2   | 0.0025  |       7 |
+ | with LGO:Composite (0 outputs)                     |      7.3  |       140 |        2.7 | 0.00028 |       7 |
+ | with LGO:Screen                                    |      7.4  |       140 |        2.7 | 0.00021 |       8 |
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
 
 
