@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-08-01'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2017-08-04'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,13 +10,16 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
     modules => {
-        'Log::ger' => {version=>'0.019'},
+        'Log::ger' => {version=>'0.023'},
         'Log::ger::Plugin::MultilevelLog' => {},
         'Log::ger::Plugin::OptAway' => {},
         'Log::Any' => {},
         'Log::Fast' => {},
         'Log::Log4perl' => {},
         'Log::Log4perl::Tiny' => {},
+        'Log::Contextual' => {},
+        'Log::Contextual::SimpleLogger' => {},
+        'Log::Dispatchouli' => {},
     },
     participants => [
         {
@@ -108,7 +111,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.011 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-01.
+This document describes version 0.012 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-04.
 
 =head1 SYNOPSIS
 
@@ -128,17 +131,23 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<Log::Any> 1.049
 
+L<Log::Contextual> 0.007001
+
+L<Log::Contextual::SimpleLogger> 0.007001
+
+L<Log::Dispatchouli> 2.015
+
 L<Log::Fast> v2.0.0
 
 L<Log::Log4perl> 1.49
 
 L<Log::Log4perl::Tiny> 1.4.0
 
-L<Log::ger> 0.020
+L<Log::ger> 0.023
 
-L<Log::ger::Plugin::MultilevelLog> 0.020
+L<Log::ger::Plugin::MultilevelLog> 0.023
 
-L<Log::ger::Plugin::OptAway> 0.004
+L<Log::ger::Plugin::OptAway> 0.005
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -284,22 +293,22 @@ Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
  +------------------------------------------+-----------+-------+------------+-----------+---------+
  | participant                              | rate (/s) |  time | vs_slowest |  errors   | samples |
  +------------------------------------------+-----------+-------+------------+-----------+---------+
- | Log::Contextual+Log4perl                 |     0.17  | 5.8   |       1    |   0.021   |       6 |
- | Log::Contextual+SimpleLogger             |     0.177 | 5.65  |       1.02 |   0.0056  |       6 |
- | Log::Log4perl::Tiny-1mil_trace           |     0.847 | 1.18  |       4.88 |   0.00066 |       6 |
- | Log::Dispatchouli                        |     1.25  | 0.803 |       7.18 |   0.00031 |       6 |
- | Log::Any-null_adapter-1mil_log_trace     |     1.7   | 0.6   |       9.6  |   0.0011  |       7 |
- | Log::Fast-1mil_is_debug                  |     2.2   | 0.46  |      13    |   0.0019  |       6 |
- | Log::Any-no_adapter-1mil_is_trace        |     2.5   | 0.4   |      15    |   0.00084 |       6 |
- | Log::Any-null_adapter-1mil_is_trace      |     2.5   | 0.4   |      15    |   0.0017  |       6 |
- | Log::Log4perl-easy-1mil_trace            |     3.16  | 0.316 |      18.2  |   0.00022 |       6 |
- | Log::Any-no_adapter-1mil_log_trace       |     6.4   | 0.16  |      37    |   0.00051 |       6 |
- | Log::Fast-1mil_DEBUG                     |     6.4   | 0.16  |      37    |   0.0006  |       7 |
- | Log::ger+LGP:MutilevelLog-1mil_log_trace |     9     | 0.1   |      50    |   0.0023  |       7 |
- | Log::ger+LGP:MutilevelLog-1mil_log_6     |     9.3   | 0.11  |      53    |   0.00041 |       6 |
- | Log::ger-1mil_log_is_trace               |     9.62  | 0.104 |      55.4  | 3.3e-05   |       6 |
- | Log::ger-1mil_log_trace                  |    10     | 0.099 |      58    |   0.00078 |       7 |
- | Log::ger+LGP:OptAway-1mil_log_trace      |    24     | 0.042 |     140    |   0.0002  |       6 |
+ | Log::Contextual+Log4perl                 |     0.17  | 5.89  |       1    |   0.0055  |       6 |
+ | Log::Contextual+SimpleLogger             |     0.176 | 5.7   |       1.03 |   0.001   |       6 |
+ | Log::Log4perl::Tiny-1mil_trace           |     0.84  | 1.2   |       5    |   0.0022  |       6 |
+ | Log::Dispatchouli                        |     1.2   | 0.84  |       7    |   0.0037  |       6 |
+ | Log::Any-null_adapter-1mil_log_trace     |     1.6   | 0.61  |       9.7  |   0.00084 |       6 |
+ | Log::Fast-1mil_is_debug                  |     2.1   | 0.48  |      12    |   0.00058 |       6 |
+ | Log::Any-no_adapter-1mil_is_trace        |     2.4   | 0.41  |      14    |   0.0018  |       6 |
+ | Log::Any-null_adapter-1mil_is_trace      |     2.5   | 0.41  |      14    |   0.0019  |       6 |
+ | Log::Log4perl-easy-1mil_trace            |     3.1   | 0.32  |      18    |   0.00064 |       6 |
+ | Log::Fast-1mil_DEBUG                     |     6.3   | 0.16  |      37    |   0.00038 |       6 |
+ | Log::Any-no_adapter-1mil_log_trace       |     6.4   | 0.16  |      38    |   0.00031 |       6 |
+ | Log::ger+LGP:MutilevelLog-1mil_log_6     |     9.06  | 0.11  |      53.4  | 9.3e-05   |       6 |
+ | Log::ger+LGP:MutilevelLog-1mil_log_trace |     9.12  | 0.11  |      53.7  | 8.4e-05   |       6 |
+ | Log::ger-1mil_log_is_trace               |     9.3   | 0.11  |      55    |   0.00026 |       9 |
+ | Log::ger-1mil_log_trace                  |    10     | 0.098 |      60    |   0.00013 |       6 |
+ | Log::ger+LGP:OptAway-1mil_log_trace      |    22     | 0.046 |     130    |   9e-05   |       6 |
  +------------------------------------------+-----------+-------+------------+-----------+---------+
 
 
