@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::StringLevel;
 
-our $DATE = '2017-08-01'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2017-08-04'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,7 @@ our $scenario = {
         },
     ],
     datasets => [
-        {args=>{level=>1}},
+        {args=>{level=>10}},
         {args=>{level=>'warn'}},
     ],
 };
@@ -38,7 +38,7 @@ Bencher::Scenario::LogGer::StringLevel - Benchmark string_level()
 
 =head1 VERSION
 
-This document describes version 0.011 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-01.
+This document describes version 0.012 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-04.
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Util> 0.020
+L<Log::ger::Util> 0.023
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -80,7 +80,7 @@ Function call template:
 
 =over
 
-=item * 1
+=item * 10
 
 =item * warn
 
@@ -96,8 +96,8 @@ Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
  +---------+-----------+-----------+------------+---------+---------+
  | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | 1       |    760000 |      1300 |       1    |   3e-09 |      25 |
- | warn    |   4240000 |       236 |       5.57 | 1.4e-10 |      20 |
+ | 10      |   1000000 |       980 |        1   | 1.9e-09 |      24 |
+ | warn    |   3800000 |       260 |        3.8 | 1.5e-09 |      25 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
@@ -107,8 +107,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::StringLevel --module-s
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      | 0.56                         | 4                  | 20             |      11   |                    5.3 |          1 | 3.7e-05 |      20 |
- | perl -e1 (baseline) | 1.3                          | 4.7                | 20             |       5.7 |                    0   |          2 | 3.7e-05 |      20 |
+ | Log::ger::Util      | 0.56                         | 4                  | 20             |        13 |                      7 |        1   | 4.5e-05 |      20 |
+ | perl -e1 (baseline) | 1.3                          | 4.8                | 20             |         6 |                      0 |        2.2 | 1.8e-05 |      21 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
