@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::InitTarget;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,60 +8,60 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00073,
+        errors => 0.00019,
         participant => "with LGO:Composite (Screen+File & pattern layouts)",
+        rate => 2.76,
+        samples => 8,
+        time => 363,
+        vs_slowest => 1,
+      },
+      {
+        errors => 0.00074,
+        participant => "default",
         rate => 2.8,
-        samples => 7,
+        samples => 8,
         time => 350,
         vs_slowest => 1,
       },
       {
-        errors => 0.00023,
-        participant => "default",
-        rate => 2.93,
-        samples => 9,
-        time => 341,
-        vs_slowest => 1.03,
-      },
-      {
-        errors => 0.00013,
+        errors => 0.0008,
         participant => "with LGO:Composite (Screen+File)",
-        rate => 3.03,
+        rate => 3,
         samples => 7,
-        time => 330,
-        vs_slowest => 1.07,
+        time => 340,
+        vs_slowest => 1.1,
       },
       {
-        errors => 0.00013,
+        errors => 0.00074,
         participant => "with LGO:Composite (Screen)",
-        rate => 3.96,
-        samples => 8,
-        time => 252,
+        rate => 4,
+        samples => 7,
+        time => 250,
         vs_slowest => 1.4,
       },
       {
-        errors => 0.00012,
+        errors => 0.0025,
         participant => "with LGO:File",
-        rate => 7.22,
+        rate => 5,
         samples => 7,
-        time => 139,
-        vs_slowest => 2.55,
+        time => 200,
+        vs_slowest => 2,
       },
       {
-        errors => 0.00022,
+        errors => 0.00028,
         participant => "with LGO:Composite (0 outputs)",
         rate => 7.3,
         samples => 7,
         time => 140,
-        vs_slowest => 2.6,
+        vs_slowest => 2.7,
       },
       {
-        errors => 0.00027,
+        errors => 0.00021,
         participant => "with LGO:Screen",
-        rate => 7.3,
-        samples => 7,
+        rate => 7.4,
+        samples => 8,
         time => 140,
-        vs_slowest => 2.6,
+        vs_slowest => 2.7,
       },
     ],
     {
@@ -165,7 +165,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2696.878,
+                                              speed                        => 3214.675,
                                               stepping                     => 7,
                                             },
                                             {
@@ -260,7 +260,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.851,
+                                              speed                        => 3244.101,
                                               stepping                     => 7,
                                             },
                                             {
@@ -355,7 +355,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2194.218,
+                                              speed                        => "3252.820",
                                               stepping                     => 7,
                                             },
                                             {
@@ -450,11 +450,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2675.082,
+                                              speed                        => 3213.949,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 15.7337400913239,
+      "func.elapsed_time"              => 16.037036895752,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => "1.040",
@@ -495,9 +495,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1499942633,
       "func.scenario_module_sha1sum"   => "04369046d22a6d1e2ce7ae2fc07be5e54ddf2e04",
       "func.scenario_module_sha256sum" => "733fb6fa020e5d8133f3addf99e97085c8878254367f5d714a603650c8820b2f",
-      "func.time_end"                  => 1501567358.06204,
+      "func.time_end"                  => 1501853030.24724,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501567342.3283,
+      "func.time_start"                => 1501853014.2102,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
