@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::LayoutStartup;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,44 +8,44 @@ our $results = [
     "OK",
     [
       {
-        errors => 3.9e-05,
-        participant => "load-JSON",
-        rate => 67,
-        samples => 21,
-        time => 15,
-        vs_slowest => 1,
-      },
-      {
-        errors => 3.5e-05,
+        errors => 0.00015,
         participant => "load-YAML",
-        rate => 67,
+        rate => 55,
         samples => 21,
-        time => 15,
+        time => 18,
         vs_slowest => 1,
       },
       {
-        errors => 3.4e-05,
+        errors => 6.6e-05,
+        participant => "load-JSON",
+        rate => 59,
+        samples => 20,
+        time => 17,
+        vs_slowest => 1.1,
+      },
+      {
+        errors => 0.00011,
         participant => "load-LTSV",
-        rate => 69,
+        rate => 61,
         samples => 20,
-        time => 14,
-        vs_slowest => 1,
+        time => 16,
+        vs_slowest => 1.1,
       },
       {
-        errors => 2.9e-05,
+        errors => 0.00012,
         participant => "load-Pattern",
-        rate => 69,
-        samples => 21,
-        time => 14,
-        vs_slowest => 1,
+        rate => 61,
+        samples => 20,
+        time => 16,
+        vs_slowest => 1.1,
       },
       {
-        errors => 5.9e-05,
+        errors => 4.6e-05,
         participant => "baseline",
-        rate => 200,
+        rate => 190,
         samples => 20,
-        time => 5,
-        vs_slowest => 3,
+        time => 5.3,
+        vs_slowest => 3.4,
       },
     ],
     {
@@ -149,7 +149,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3214.554,
+                                              speed                        => "3230.660",
                                               stepping                     => 7,
                                             },
                                             {
@@ -244,7 +244,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3228.117,
+                                              speed                        => 3216.976,
                                               stepping                     => 7,
                                             },
                                             {
@@ -339,7 +339,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "3234.050",
+                                              speed                        => 3205.714,
                                               stepping                     => 7,
                                             },
                                             {
@@ -434,11 +434,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3219.519,
+                                              speed                        => 3204.261,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.8580060005188,
+      "func.elapsed_time"              => 1.96169209480286,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => "1.040",
@@ -483,9 +483,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1499219367,
       "func.scenario_module_sha1sum"   => "d7c9b98e30622206fbbf957960dbedb4df39dfb0",
       "func.scenario_module_sha256sum" => "51f457d0cc5b3373aca89a08fd42501b541acbe2ad3121a37756a35e8c3e2cdb",
-      "func.time_end"                  => 1501567360.22092,
+      "func.time_end"                  => 1501853032.50487,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501567358.36292,
+      "func.time_start"                => 1501853030.54318,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
