@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,132 +8,132 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.021,
+        errors => 0.0055,
         participant => "Log::Contextual+Log4perl",
         rate => 0.17,
         samples => 6,
-        time => 5.8,
+        time => 5.89,
         vs_slowest => 1,
       },
       {
-        errors => 0.0056,
+        errors => 0.001,
         participant => "Log::Contextual+SimpleLogger",
-        rate => 0.177,
+        rate => 0.176,
         samples => 6,
-        time => 5.65,
-        vs_slowest => 1.02,
+        time => 5.7,
+        vs_slowest => 1.03,
       },
       {
-        errors => 0.00066,
+        errors => 0.0022,
         participant => "Log::Log4perl::Tiny-1mil_trace",
-        rate => 0.847,
+        rate => 0.84,
         samples => 6,
-        time => 1.18,
-        vs_slowest => 4.88,
+        time => 1.2,
+        vs_slowest => 5,
       },
       {
-        errors => 0.00031,
+        errors => 0.0037,
         participant => "Log::Dispatchouli",
-        rate => 1.25,
+        rate => 1.2,
         samples => 6,
-        time => 0.803,
-        vs_slowest => 7.18,
-      },
-      {
-        errors => 0.0011,
-        participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 1.7,
-        samples => 7,
-        time => 0.6,
-        vs_slowest => 9.6,
-      },
-      {
-        errors => 0.0019,
-        participant => "Log::Fast-1mil_is_debug",
-        rate => 2.2,
-        samples => 6,
-        time => 0.46,
-        vs_slowest => 13,
+        time => 0.84,
+        vs_slowest => 7,
       },
       {
         errors => 0.00084,
-        participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 2.5,
+        participant => "Log::Any-null_adapter-1mil_log_trace",
+        rate => 1.6,
         samples => 6,
-        time => 0.4,
-        vs_slowest => 15,
+        time => 0.61,
+        vs_slowest => 9.7,
       },
       {
-        errors => 0.0017,
+        errors => 0.00058,
+        participant => "Log::Fast-1mil_is_debug",
+        rate => 2.1,
+        samples => 6,
+        time => 0.48,
+        vs_slowest => 12,
+      },
+      {
+        errors => 0.0018,
+        participant => "Log::Any-no_adapter-1mil_is_trace",
+        rate => 2.4,
+        samples => 6,
+        time => 0.41,
+        vs_slowest => 14,
+      },
+      {
+        errors => 0.0019,
         participant => "Log::Any-null_adapter-1mil_is_trace",
         rate => 2.5,
         samples => 6,
-        time => 0.4,
-        vs_slowest => 15,
+        time => 0.41,
+        vs_slowest => 14,
       },
       {
-        errors => 0.00022,
+        errors => 0.00064,
         participant => "Log::Log4perl-easy-1mil_trace",
-        rate => 3.16,
+        rate => 3.1,
         samples => 6,
-        time => 0.316,
-        vs_slowest => 18.2,
+        time => 0.32,
+        vs_slowest => 18,
       },
       {
-        errors => 0.00051,
+        errors => 0.00038,
+        participant => "Log::Fast-1mil_DEBUG",
+        rate => 6.3,
+        samples => 6,
+        time => 0.16,
+        vs_slowest => 37,
+      },
+      {
+        errors => 0.00031,
         participant => "Log::Any-no_adapter-1mil_log_trace",
         rate => 6.4,
         samples => 6,
         time => 0.16,
-        vs_slowest => 37,
+        vs_slowest => 38,
       },
       {
-        errors => 0.0006,
-        participant => "Log::Fast-1mil_DEBUG",
-        rate => 6.4,
-        samples => 7,
-        time => 0.16,
-        vs_slowest => 37,
-      },
-      {
-        errors => 0.0023,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
-        rate => 9,
-        samples => 7,
-        time => 0.1,
-        vs_slowest => 50,
-      },
-      {
-        errors => 0.00041,
+        errors => 9.3e-05,
         participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
-        rate => 9.3,
+        rate => 9.06,
         samples => 6,
         time => 0.11,
-        vs_slowest => 53,
+        vs_slowest => 53.4,
       },
       {
-        errors => 3.3e-05,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 9.62,
+        errors => 8.4e-05,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
+        rate => 9.12,
         samples => 6,
-        time => 0.104,
-        vs_slowest => 55.4,
+        time => 0.11,
+        vs_slowest => 53.7,
       },
       {
-        errors => 0.00078,
+        errors => 0.00026,
+        participant => "Log::ger-1mil_log_is_trace",
+        rate => 9.3,
+        samples => 9,
+        time => 0.11,
+        vs_slowest => 55,
+      },
+      {
+        errors => 0.00013,
         participant => "Log::ger-1mil_log_trace",
         rate => 10,
-        samples => 7,
-        time => 0.099,
-        vs_slowest => 58,
+        samples => 6,
+        time => 0.098,
+        vs_slowest => 60,
       },
       {
-        errors => 0.0002,
+        errors => 9e-05,
         participant => "Log::ger+LGP:OptAway-1mil_log_trace",
-        rate => 24,
+        rate => 22,
         samples => 6,
-        time => 0.042,
-        vs_slowest => 140,
+        time => 0.046,
+        vs_slowest => 130,
       },
     ],
     {
@@ -237,7 +237,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3247.492,
+                                              speed                        => 3209.347,
                                               stepping                     => 7,
                                             },
                                             {
@@ -332,7 +332,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3250.035,
+                                              speed                        => "3257.300",
                                               stepping                     => 7,
                                             },
                                             {
@@ -427,7 +427,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3256.816,
+                                              speed                        => 3142.261,
                                               stepping                     => 7,
                                             },
                                             {
@@ -522,26 +522,29 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3245.675,
+                                              speed                        => 3100.363,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 136.550081968307,
+      "func.elapsed_time"              => 143.751966953278,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => "1.040",
+                                            "__PACKAGE__"                           => "1.040",
                                             "Bencher::Scenario::LogGer::NullOutput" => undef,
-                                            "Benchmark::Dumb" => 0.111,
-                                            "Devel::Platform::Info" => 0.16,
-                                            "Log::Any" => 1.049,
-                                            "Log::Fast" => "v2.0.0",
-                                            "Log::ger" => "0.020",
-                                            "Log::ger::Plugin::MultilevelLog" => "0.020",
-                                            "Log::ger::Plugin::OptAway" => 0.004,
-                                            "Log::Log4perl" => 1.49,
-                                            "Log::Log4perl::Tiny" => "1.4.0",
-                                            "perl" => "v5.26.0",
-                                            "Sys::Info" => 0.78,
+                                            "Benchmark::Dumb"                       => 0.111,
+                                            "Devel::Platform::Info"                 => 0.16,
+                                            "Log::Any"                              => 1.049,
+                                            "Log::Contextual"                       => 0.007001,
+                                            "Log::Contextual::SimpleLogger"         => 0.007001,
+                                            "Log::Dispatchouli"                     => 2.015,
+                                            "Log::Fast"                             => "v2.0.0",
+                                            "Log::ger"                              => 0.023,
+                                            "Log::ger::Plugin::MultilevelLog"       => 0.023,
+                                            "Log::ger::Plugin::OptAway"             => 0.005,
+                                            "Log::Log4perl"                         => 1.49,
+                                            "Log::Log4perl::Tiny"                   => "1.4.0",
+                                            "perl"                                  => "v5.26.0",
+                                            "Sys::Info"                             => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 15]],
@@ -570,13 +573,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "c34f6af7d97c52ab6574bb4d5b5dee59",
-      "func.scenario_module_mtime"     => 1501567073,
-      "func.scenario_module_sha1sum"   => "eaac62da5f7838e0171992fff2dcbddf169a7de4",
-      "func.scenario_module_sha256sum" => "45aae8b616216d6db42208ee8ebad6d06ba4478709036fbe16222d9d1c236bc2",
-      "func.time_end"                  => 1501567515.4285,
+      "func.scenario_module_md5sum"    => "e15c0e5d1013f4fddebc4adcc93c7604",
+      "func.scenario_module_mtime"     => 1501852783,
+      "func.scenario_module_sha1sum"   => "8760dcc0d89761e2341a4926f7f6eb0391d846f5",
+      "func.scenario_module_sha256sum" => "1ddb4d9c4b215449754bda1a28ef12faccae5138b6f898a720c62621f1798782",
+      "func.time_end"                  => 1501853195.62431,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1501567378.87842,
+      "func.time_start"                => 1501853051.87234,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s"],
       "table.fields"                   => [
