@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NumericLevel;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -9,19 +9,19 @@ our $results = [
     [
       {
         dataset    => "warn",
-        errors     => 9.3e-11,
-        rate       => 2170000,
+        errors     => 5.8e-11,
+        rate       => 2290000,
         samples    => 20,
-        time       => 461,
+        time       => 436,
         vs_slowest => 1,
       },
       {
-        dataset    => 1,
-        errors     => 9e-10,
-        rate       => 2600000,
-        samples    => 20,
-        time       => 380,
-        vs_slowest => 1.2,
+        dataset    => 10,
+        errors     => 2.5e-10,
+        rate       => 2480000,
+        samples    => 22,
+        time       => 404,
+        vs_slowest => 1.08,
       },
     ],
     {
@@ -125,7 +125,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3295.687,
+                                              speed                        => 3211.648,
                                               stepping                     => 7,
                                             },
                                             {
@@ -220,7 +220,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3254.152,
+                                              speed                        => 3193.121,
                                               stepping                     => 7,
                                             },
                                             {
@@ -315,7 +315,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3287.089,
+                                              speed                        => 3267.593,
                                               stepping                     => 7,
                                             },
                                             {
@@ -410,18 +410,18 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3248.218,
+                                              speed                        => 3142.625,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0521581172943115,
+      "func.elapsed_time"              => 0.0548899173736572,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => "1.040",
                                             "Bencher::Scenario::LogGer::NumericLevel" => undef,
                                             "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "Log::ger::Util" => "0.020",
+                                            "Log::ger::Util" => 0.023,
                                             "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
@@ -452,13 +452,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NumericLevel",
-      "func.scenario_module_md5sum"    => "d4c1a3955e444badfcfc9399ad49379b",
-      "func.scenario_module_mtime"     => 1499219367,
-      "func.scenario_module_sha1sum"   => "5d5db7ba9a4229c19df61542f84537d6596f8ac0",
-      "func.scenario_module_sha256sum" => "a6efeb768a00fb37f6801e6aa555b5daaae141235f27a746936fecf226630657",
-      "func.time_end"                  => 1501567515.66481,
+      "func.scenario_module_md5sum"    => "47850c54095a12b638ea340401bca643",
+      "func.scenario_module_mtime"     => 1501851634,
+      "func.scenario_module_sha1sum"   => "278771b127381816b42d9f13ba18a9ceef40312a",
+      "func.scenario_module_sha256sum" => "cd83a7931d9409b46d31ed8ffc2b982441ca840ce3d0ca2e5abf77a786dc813d",
+      "func.time_end"                  => 1501853195.86687,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1501567515.61265,
+      "func.time_start"                => 1501853195.81198,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ns"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
