@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,220 +8,204 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0002,
-        participant => "init-with-LogDispatchOutput",
-        rate => 8.7,
-        samples => 23,
-        time => 120,
+        errors => 0.00021,
+        participant => "init-with-FileWriteRotate",
+        rate => 18,
+        samples => 20,
+        time => 57,
         vs_slowest => 1,
       },
       {
-        errors => 0.0001,
-        participant => "init-with-FileWriteRotate",
-        rate => 20,
-        samples => 20,
-        time => 50,
-        vs_slowest => 2.3,
-      },
-      {
-        errors => 6e-05,
+        errors => 8.2e-05,
         participant => "init-with-Syslog",
-        rate => 30,
-        samples => 21,
-        time => 33,
-        vs_slowest => 3.5,
+        rate => 26,
+        samples => 20,
+        time => 38,
+        vs_slowest => 1.5,
       },
       {
-        errors => 6.1e-05,
+        errors => 5.3e-05,
         participant => "init-with-LogAny",
-        rate => 49,
+        rate => 42,
+        samples => 20,
+        time => 24,
+        vs_slowest => 2.4,
+      },
+      {
+        errors => 7.2e-05,
+        participant => "init-with-Composite",
+        rate => 47,
+        samples => 20,
+        time => 21,
+        vs_slowest => 2.7,
+      },
+      {
+        errors => 4.6e-05,
+        participant => "init-with-DirWriteRotate",
+        rate => 51,
         samples => 20,
         time => 20,
-        vs_slowest => 5.7,
+        vs_slowest => 2.9,
       },
       {
-        errors => 5.9e-05,
-        participant => "init-with-Composite",
-        rate => 53,
+        errors => 7.4e-05,
+        participant => "init-with-ArrayRotate",
+        rate => 65,
         samples => 21,
-        time => 19,
-        vs_slowest => 6.1,
+        time => 15,
+        vs_slowest => 3.7,
       },
       {
-        errors => 4.1e-05,
-        participant => "init-with-DirWriteRotate",
-        rate => 58,
-        samples => 20,
-        time => 17,
-        vs_slowest => 6.7,
-      },
-      {
-        errors => 3.4e-05,
-        participant => "init-with-File",
-        rate => 74,
-        samples => 21,
-        time => 13,
-        vs_slowest => 8.6,
-      },
-      {
-        errors => 5.4e-05,
+        errors => 6.7e-05,
         participant => "init-with-Screen",
-        rate => 75,
-        samples => 21,
-        time => 13,
-        vs_slowest => 8.6,
+        rate => 65,
+        samples => 20,
+        time => 15,
+        vs_slowest => 3.7,
       },
       {
         errors => 3.8e-05,
-        participant => "init-with-Callback",
-        rate => 75,
+        participant => "init-with-File",
+        rate => 65,
         samples => 20,
-        time => 13,
-        vs_slowest => 8.7,
+        time => 15,
+        vs_slowest => 3.7,
       },
       {
-        errors => 2.3e-05,
+        errors => 1.8e-05,
         participant => "init-with-String",
-        rate => 75,
+        rate => 65,
         samples => 20,
-        time => 13,
-        vs_slowest => 8.7,
+        time => 15,
+        vs_slowest => 3.7,
+      },
+      {
+        errors => 6.7e-05,
+        participant => "init-with-Null",
+        rate => 66,
+        samples => 20,
+        time => 15,
+        vs_slowest => 3.7,
       },
       {
         errors => 3.9e-05,
         participant => "init-with-Array",
-        rate => 76,
-        samples => 21,
-        time => 13,
-        vs_slowest => 8.7,
+        rate => 66,
+        samples => 20,
+        time => 15,
+        vs_slowest => 3.8,
       },
       {
         errors => 2.5e-05,
-        participant => "init-with-ArrayWithLimits",
-        rate => 76,
+        participant => "init-with-Callback",
+        rate => 67,
         samples => 20,
-        time => 13,
-        vs_slowest => 8.7,
+        time => 15,
+        vs_slowest => 3.8,
       },
       {
-        errors => 3e-05,
-        participant => "init-with-Null",
-        rate => 76,
-        samples => 21,
-        time => 13,
-        vs_slowest => 8.8,
-      },
-      {
-        errors => 3.8e-05,
+        errors => 5.9e-05,
         participant => "load-Screen",
-        rate => 83,
+        rate => 76,
         samples => 20,
-        time => 12,
-        vs_slowest => 9.6,
+        time => 13,
+        vs_slowest => 4.3,
       },
       {
-        errors => 3.3e-05,
-        participant => "load-LogDispatchOutput",
-        rate => 86,
-        samples => 20,
-        time => 12,
-        vs_slowest => 9.9,
-      },
-      {
-        errors => 4.9e-05,
+        errors => 4.7e-05,
         participant => "load-Composite",
+        rate => 100,
+        samples => 20,
+        time => 9.8,
+        vs_slowest => 5.8,
+      },
+      {
+        errors => 7.4e-05,
+        participant => "load-LogAny",
         rate => 110,
         samples => 20,
-        time => 9.3,
-        vs_slowest => 12,
+        time => 9.2,
+        vs_slowest => 6.1,
       },
       {
-        errors => 6e-05,
+        errors => 4.4e-05,
+        participant => "load-Callback",
+        rate => 110,
+        samples => 20,
+        time => 9.2,
+        vs_slowest => 6.2,
+      },
+      {
+        errors => 5.8e-05,
         participant => "load-String",
-        rate => 120,
+        rate => 110,
         samples => 20,
-        time => 8.5,
-        vs_slowest => 14,
+        time => 9.1,
+        vs_slowest => 6.2,
       },
       {
-        errors => 2.9e-05,
-        participant => "load-Syslog",
-        rate => 120,
-        samples => 20,
-        time => 8.5,
-        vs_slowest => 14,
-      },
-      {
-        errors => 7e-05,
+        errors => 5.4e-05,
         participant => "load-Array",
-        rate => 120,
+        rate => 110,
         samples => 20,
-        time => 8.5,
-        vs_slowest => 14,
+        time => 9.1,
+        vs_slowest => 6.2,
+      },
+      {
+        errors => 4.2e-05,
+        participant => "load-ArrayRotate",
+        rate => 110,
+        samples => 20,
+        time => 9.1,
+        vs_slowest => 6.2,
       },
       {
         errors => 2.3e-05,
-        participant => "load-LogAny",
-        rate => 120,
+        participant => "load-Syslog",
+        rate => 110,
         samples => 20,
-        time => 8.4,
-        vs_slowest => 14,
+        time => 9.1,
+        vs_slowest => 6.2,
       },
       {
-        errors => 4.5e-05,
-        participant => "load-DirWriteRotate",
-        rate => 120,
-        samples => 20,
-        time => 8.4,
-        vs_slowest => 14,
-      },
-      {
-        errors => 3.7e-05,
-        participant => "load-File",
-        rate => 120,
-        samples => 20,
-        time => 8.3,
-        vs_slowest => 14,
-      },
-      {
-        errors => 2.1e-05,
-        participant => "load-ArrayWithLimits",
-        rate => 120,
-        samples => 20,
-        time => 8.3,
-        vs_slowest => 14,
-      },
-      {
-        errors => 4.1e-05,
+        errors => 6.8e-05,
         participant => "load-FileWriteRotate",
-        rate => 120,
-        samples => 20,
-        time => 8.3,
-        vs_slowest => 14,
+        rate => 110,
+        samples => 21,
+        time => 9.1,
+        vs_slowest => 6.2,
       },
       {
-        errors => 1.3e-05,
-        participant => "load-Callback",
-        rate => 120,
+        errors => 2.4e-05,
+        participant => "load-File",
+        rate => 110,
         samples => 20,
-        time => 8.3,
-        vs_slowest => 14,
+        time => 9,
+        vs_slowest => 6.3,
       },
       {
-        errors => 4.5e-05,
+        errors => 4.2e-05,
+        participant => "load-DirWriteRotate",
+        rate => 110,
+        samples => 20,
+        time => 8.9,
+        vs_slowest => 6.4,
+      },
+      {
+        errors => 3.6e-05,
         participant => "load-Null",
-        rate => 170,
+        rate => 150,
         samples => 20,
-        time => 6,
-        vs_slowest => 19,
+        time => 6.5,
+        vs_slowest => 8.7,
       },
       {
-        errors => 5.7e-05,
+        errors => 4.4e-05,
         participant => "baseline",
         rate => 170,
         samples => 20,
-        time => 5.8,
-        vs_slowest => 20,
+        time => 6,
+        vs_slowest => 9.4,
       },
     ],
     {
@@ -325,7 +309,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3178.589,
+                                              speed                        => 3294.355,
                                               stepping                     => 7,
                                             },
                                             {
@@ -420,7 +404,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3197.722,
+                                              speed                        => 3227.753,
                                               stepping                     => 7,
                                             },
                                             {
@@ -515,7 +499,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3270.015,
+                                              speed                        => 3258.753,
                                               stepping                     => 7,
                                             },
                                             {
@@ -610,35 +594,34 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3059.554,
+                                              speed                        => 3275.585,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 12.5067059993744,
+      "func.elapsed_time"              => 9.64052104949951,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => "1.040",
                                             "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                             "Benchmark::Dumb"                          => 0.111,
                                             "Devel::Platform::Info"                    => 0.16,
-                                            "Log::ger::Output::Array"                  => "0.020",
-                                            "Log::ger::Output::ArrayWithLimits"        => 0.001,
+                                            "Log::ger::Output::Array"                  => 0.023,
+                                            "Log::ger::Output::ArrayRotate"            => 0.001,
                                             "Log::ger::Output::Callback"               => 0.002,
                                             "Log::ger::Output::Composite"              => 0.007,
                                             "Log::ger::Output::DirWriteRotate"         => 0.002,
-                                            "Log::ger::Output::File"                   => 0.002,
-                                            "Log::ger::Output::FileWriteRotate"        => 0.001,
+                                            "Log::ger::Output::File"                   => 0.006,
+                                            "Log::ger::Output::FileWriteRotate"        => 0.002,
                                             "Log::ger::Output::LogAny"                 => 0.006,
-                                            "Log::ger::Output::LogDispatchOutput"      => 0.001,
-                                            "Log::ger::Output::Null"                   => "0.020",
-                                            "Log::ger::Output::Screen"                 => 0.005,
-                                            "Log::ger::Output::String"                 => "0.020",
+                                            "Log::ger::Output::Null"                   => 0.023,
+                                            "Log::ger::Output::Screen"                 => 0.007,
+                                            "Log::ger::Output::String"                 => 0.023,
                                             "Log::ger::Output::Syslog"                 => 0.001,
                                             "perl"                                     => "v5.26.0",
                                             "Sys::Info"                                => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 26]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 24]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "jessie",
@@ -664,13 +647,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::OutputStartup",
-      "func.scenario_module_md5sum"    => "2c922207574cc87cd6748d198b67109b",
-      "func.scenario_module_mtime"     => 1499943709,
-      "func.scenario_module_sha1sum"   => "129836f865b60d24782e42579d87b86148024946",
-      "func.scenario_module_sha256sum" => "3cbac91485ccf4718cbfa781a1eeefb04dcca0d3b74586905682aad6e73d6ed8",
-      "func.time_end"                  => 1501567529.49803,
+      "func.scenario_module_md5sum"    => "f05ee7eefd2e12d994e77ad165a152ab",
+      "func.scenario_module_mtime"     => 1501852763,
+      "func.scenario_module_sha1sum"   => "d1cb23bd40993b0438d71bba57064482d531ded8",
+      "func.scenario_module_sha256sum" => "a20a22b9dda21be3cd39583d0a92e817df9600c345417ee0a4c9587c52a7440c",
+      "func.time_end"                  => 1501853206.91214,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501567516.99133,
+      "func.time_start"                => 1501853197.27162,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
