@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Overhead;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,103 +8,191 @@ our $results = [
     "OK",
     [
       {
-        code_overhead_time => 78.2,
-        errors => 0.00011,
+        code_overhead_time => 124,
+        errors => 0.00023,
+        participant => "use Log::Dispatchouli;",
+        proc_private_dirty_size => 568,
+        proc_rss_size => 4,
+        proc_size => 20,
+        samples => 20,
+        time => 130,
+        vs_slowest => 1,
+      },
+      {
+        code_overhead_time => 88,
+        errors => 0.00017,
         participant => "use Log::Contextual qw(:log);",
         proc_private_dirty_size => 572,
         proc_rss_size => 4,
         proc_size => 20,
         samples => 20,
-        time => 84,
-        vs_slowest => 1,
+        time => 94,
+        vs_slowest => 1.3,
       },
       {
-        code_overhead_time => 18.2,
-        errors => 6.6e-05,
+        code_overhead_time => 39,
+        errors => 0.00013,
+        participant => "use Log::Log4perl;",
+        proc_private_dirty_size => 568,
+        proc_rss_size => 3.9,
+        proc_size => 20,
+        samples => 20,
+        time => 45,
+        vs_slowest => 2.8,
+      },
+      {
+        code_overhead_time => 21,
+        errors => 7.9e-05,
         participant => "use Log::ger::App; use Log::ger;",
         proc_private_dirty_size => 572,
+        proc_rss_size => 3.9,
+        proc_size => 20,
+        samples => 20,
+        time => 27,
+        vs_slowest => 4.6,
+      },
+      {
+        code_overhead_time => 19,
+        errors => 3.6e-05,
+        participant => "use Log::Log4perl::Tiny;",
+        proc_private_dirty_size => 572,
         proc_rss_size => 4,
         proc_size => 20,
         samples => 20,
-        time => 24,
-        vs_slowest => 3.4,
-      },
-      {
-        code_overhead_time => 11.2,
-        errors => 2e-05,
-        participant => "use Log::ger::App;",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 20,
-        time => 17,
+        time => 25,
         vs_slowest => 5.1,
       },
       {
-        code_overhead_time => 9.2,
-        errors => 3.8e-05,
+        code_overhead_time => 13,
+        errors => 4.3e-05,
+        participant => "use Log::ger::App;",
+        proc_private_dirty_size => 572,
+        proc_rss_size => 3.9,
+        proc_size => 20,
+        samples => 21,
+        time => 19,
+        vs_slowest => 6.7,
+      },
+      {
+        code_overhead_time => 12,
+        errors => 6.1e-05,
+        participant => "use Log::ger::Like::Log4perl;",
+        proc_private_dirty_size => 572,
+        proc_rss_size => 4,
+        proc_size => 20,
+        samples => 20,
+        time => 18,
+        vs_slowest => 6.9,
+      },
+      {
+        code_overhead_time => 12,
+        errors => 7.3e-05,
         participant => "use Log::Any q(\$log);",
         proc_private_dirty_size => 572,
         proc_rss_size => 4,
         proc_size => 20,
-        samples => 20,
-        time => 15,
-        vs_slowest => 5.6,
+        samples => 22,
+        time => 18,
+        vs_slowest => 7.1,
       },
       {
-        code_overhead_time => 9.2,
-        errors => 3.8e-05,
+        code_overhead_time => 11,
+        errors => 6.4e-05,
         participant => "use Log::Any;",
         proc_private_dirty_size => 572,
         proc_rss_size => 4,
         proc_size => 20,
         samples => 20,
-        time => 15,
-        vs_slowest => 5.8,
+        time => 17,
+        vs_slowest => 7.6,
       },
       {
-        code_overhead_time => 1,
-        errors => 5.3e-05,
-        participant => "use Log::ger; Log::ger->get_logger;",
+        code_overhead_time => 7,
+        errors => 3.9e-05,
+        participant => "use Log::ger::Output::Screen;",
+        proc_private_dirty_size => 568,
+        proc_rss_size => 4,
+        proc_size => 20,
+        samples => 20,
+        time => 13,
+        vs_slowest => 9.5,
+      },
+      {
+        code_overhead_time => 4,
+        errors => 2e-05,
+        participant => "use Log::ger::Output::Composite;",
         proc_private_dirty_size => 572,
         proc_rss_size => 3.9,
         proc_size => 20,
         samples => 20,
-        time => 6.8,
-        vs_slowest => 12,
+        time => 10,
+        vs_slowest => 13,
       },
       {
-        code_overhead_time => 0.9,
-        errors => 3.8e-05,
+        code_overhead_time => 3.9,
+        errors => 2.5e-05,
+        participant => "use Log::ger::Plugin::OptAway; use Log::ger;",
+        proc_private_dirty_size => 572,
+        proc_rss_size => 4,
+        proc_size => 20,
+        samples => 20,
+        time => 9.9,
+        vs_slowest => 13,
+      },
+      {
+        code_overhead_time => 1.4,
+        errors => 3e-05,
+        participant => "use Log::ger::Like::LogAny;",
+        proc_private_dirty_size => 568,
+        proc_rss_size => 3.9,
+        proc_size => 20,
+        samples => 20,
+        time => 7.4,
+        vs_slowest => 17,
+      },
+      {
+        code_overhead_time => 1,
+        errors => 7.2e-05,
+        participant => "use Log::ger; Log::ger->get_logger;",
+        proc_private_dirty_size => 572,
+        proc_rss_size => 4,
+        proc_size => 20,
+        samples => 20,
+        time => 7,
+        vs_slowest => 20,
+      },
+      {
+        code_overhead_time => 1,
+        errors => 7.5e-05,
         participant => "use Log::ger;",
         proc_private_dirty_size => 572,
         proc_rss_size => 4,
         proc_size => 20,
-        samples => 21,
-        time => 6.7,
-        vs_slowest => 13,
+        samples => 20,
+        time => 7,
+        vs_slowest => 20,
       },
       {
-        code_overhead_time => 0.7,
-        errors => 4.2e-05,
+        code_overhead_time => 1,
+        errors => 1.7e-05,
         participant => "use Log::ger ();",
-        proc_private_dirty_size => 572,
+        proc_private_dirty_size => 568,
         proc_rss_size => 4,
         proc_size => 20,
-        samples => 21,
-        time => 6.5,
-        vs_slowest => 13,
+        samples => 20,
+        time => 7,
+        vs_slowest => 18,
       },
       {
         code_overhead_time => 0,
-        errors => 4.8e-05,
+        errors => 6.5e-05,
         participant => "perl -e1 (baseline)",
         proc_private_dirty_size => 568,
         proc_rss_size => 4,
         proc_size => 20,
         samples => 20,
-        time => 5.8,
-        vs_slowest => 15,
+        time => 6,
+        vs_slowest => 20,
       },
     ],
     {
@@ -208,7 +296,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3254.515,
+                                              speed                        => 3159.457,
                                               stepping                     => 7,
                                             },
                                             {
@@ -303,7 +391,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3079.171,
+                                              speed                        => 3223.878,
                                               stepping                     => 7,
                                             },
                                             {
@@ -398,7 +486,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3238.773,
+                                              speed                        => "3205.230",
                                               stepping                     => 7,
                                             },
                                             {
@@ -493,11 +581,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3262.628,
+                                              speed                        => 3212.375,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 4.72650098800659,
+      "func.elapsed_time"              => 11.7200911045074,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                         => "1.040",
@@ -506,15 +594,18 @@ our $results = [
                                             "Devel::Platform::Info"               => 0.16,
                                             "Log::Any"                            => 1.049,
                                             "Log::Contextual"                     => 0.007001,
-                                            "Log::ger"                            => "0.020",
+                                            "Log::Dispatchouli"                   => 2.015,
+                                            "Log::ger"                            => 0.023,
                                             "Log::ger::App"                       => 0.003,
                                             "Log::ger::Layout::Pattern"           => 0.001,
-                                            "Log::ger::Output"                    => "0.020",
+                                            "Log::ger::Output"                    => 0.023,
+                                            "Log::Log4perl"                       => 1.49,
+                                            "Log::Log4perl::Tiny"                 => "1.4.0",
                                             "perl"                                => "v5.26.0",
                                             "Sys::Info"                           => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 8]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 17]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "jessie",
@@ -540,13 +631,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Overhead",
-      "func.scenario_module_md5sum"    => "097fd52331dde3e2d30fe1bf242a008d",
-      "func.scenario_module_mtime"     => 1501567092,
-      "func.scenario_module_sha1sum"   => "b17b6f8a542853943b370adf62b048f7e3cbbf45",
-      "func.scenario_module_sha256sum" => "6d1c35a0f33d32ff9db36d8f022f17d1538248acc10fd9f11fb48c7a8a49a60e",
-      "func.time_end"                  => 1501567538.53361,
+      "func.scenario_module_md5sum"    => "0edc3d4a26f5e2516bdf1ad69c8c206d",
+      "func.scenario_module_mtime"     => 1501851050,
+      "func.scenario_module_sha1sum"   => "1865868844b4870a6c50857d2865074b6a056d14",
+      "func.scenario_module_sha256sum" => "8470af634e0518da7fd37e1beecf5507d1b5188dffe51727d748505336531ee0",
+      "func.time_end"                  => 1501853223.58396,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501567533.80711,
+      "func.time_start"                => 1501853211.86386,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
