@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::StringLevel;
 
-our $VERSION = 0.011; # VERSION
+our $VERSION = 0.012; # VERSION
 
 our $results = [
   [
@@ -8,20 +8,20 @@ our $results = [
     "OK",
     [
       {
-        dataset    => 1,
-        errors     => 3e-09,
-        rate       => 760000,
-        samples    => 25,
-        time       => 1300,
+        dataset    => 10,
+        errors     => 1.9e-09,
+        rate       => 1000000,
+        samples    => 24,
+        time       => 980,
         vs_slowest => 1,
       },
       {
         dataset    => "warn",
-        errors     => 1.4e-10,
-        rate       => 4240000,
-        samples    => 20,
-        time       => 236,
-        vs_slowest => 5.57,
+        errors     => 1.5e-09,
+        rate       => 3800000,
+        samples    => 25,
+        time       => 260,
+        vs_slowest => 3.8,
       },
     ],
     {
@@ -125,7 +125,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3286.605,
+                                              speed                        => 3206.441,
                                               stepping                     => 7,
                                             },
                                             {
@@ -220,7 +220,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3259.843,
+                                              speed                        => 3267.109,
                                               stepping                     => 7,
                                             },
                                             {
@@ -315,7 +315,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3258.753,
+                                              speed                        => 3247.128,
                                               stepping                     => 7,
                                             },
                                             {
@@ -410,18 +410,18 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3254.636,
+                                              speed                        => 3209.589,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0526199340820312,
+      "func.elapsed_time"              => 0.0575630664825439,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => "1.040",
                                             "Bencher::Scenario::LogGer::StringLevel" => undef,
                                             "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "Log::ger::Util" => "0.020",
+                                            "Log::ger::Util" => 0.023,
                                             "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
@@ -452,13 +452,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::StringLevel",
-      "func.scenario_module_md5sum"    => "336adb160c1555a080098b2120b08a22",
-      "func.scenario_module_mtime"     => 1499219367,
-      "func.scenario_module_sha1sum"   => "3ebf05c620be02a5a18a4a3118e8bd5c581b9218",
-      "func.scenario_module_sha256sum" => "752ecc4391e9c1129a19ce3986d603ce63bbd04b54d2cfeffff84809c946ff53",
-      "func.time_end"                  => 1501567559.74565,
+      "func.scenario_module_md5sum"    => "699dd9eeb90fb630fe59b955a51204bb",
+      "func.scenario_module_mtime"     => 1501851640,
+      "func.scenario_module_sha1sum"   => "63ddba6411f232a95b1b020fc4206845a3ccd23c",
+      "func.scenario_module_sha256sum" => "39975fe7d9f2303befdcb8137f1e6d7dce889680bedd3b90287c69747890a4e0",
+      "func.time_end"                  => 1501853223.84587,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1501567559.69303,
+      "func.time_start"                => 1501853223.78831,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ns"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
